@@ -1,7 +1,7 @@
 # Copyright (C) 2008 Ioannis Tambouras <ioannis@cpan.org>. All rights reserved.
 # LICENSE:  GPLv3, eead licensing terms at  http://www.fsf.org .
 package Pg::Pcurse::Widget;
-use 5.008008;
+use v5.8;
 use Curses;
 use Curses::Widgets;
 use Carp::Assert;
@@ -480,4 +480,35 @@ Ctrl-F   data to File /tmp/pcurse.out
         };
 }
 1;
+__END__
+=head1 NAME
+
+Pg::Pcurse::Widget  - Support widgets for Pg::Pcurse
+
+=head1 SYNOPSIS
+
+  use Pg::Pcurse::Query0;
+
+=head1 DESCRIPTION
+
+Support widgets for Pg::Pcurse
+
+
+=head1 SEE ALSO
+
+Pg::Pcurse, pcurse(1)
+
+=head1 AUTHOR
+
+Ioannis Tambouras, E<lt>ioannis@cpan.org<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2008 by Ioannis Tambouras
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms of GPLv3
+
+
+=cut
 
